==> haskell-lattices-2.0.2-88-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lattices.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lattices
version:              2.0.2
visibility:           public
id:                   lattices-2.0.2-81ke987MRYbJioKmaDJnwG
key:                  lattices-2.0.2-81ke987MRYbJioKmaDJnwG
license:              BSD-3-Clause
copyright:
    (C) 2010-2015 Maximilian Bolingbroke, 2016-2019 Oleg Grenrus

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Maximilian Bolingbroke <batterseapower@hotmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             http://github.com/phadej/lattices/
synopsis:
    Fine-grained library for constructing and manipulating lattices

description:
    In mathematics, a lattice is a partially ordered set in which every two
    elements @x@ and @y@ have a unique supremum (also called a least upper bound, join, or @x /\\ y@)
    and a unique infimum (also called a greatest lower bound, meet, or @x \\/ y@).

    This package provide type-classes for different lattice types, as well
    as a class for the partial order.

category:             Math
abi:                  3bf007c491ad6b323b7c600b900adf4a
exposed:              True
exposed-modules:
    Algebra.Heyting Algebra.Heyting.Free Algebra.Heyting.Free.Expr
    Algebra.Lattice Algebra.Lattice.Divisibility
    Algebra.Lattice.Dropped Algebra.Lattice.Free
    Algebra.Lattice.Free.Final Algebra.Lattice.Levitated
    Algebra.Lattice.Lexicographic Algebra.Lattice.Lifted
    Algebra.Lattice.M2 Algebra.Lattice.M3 Algebra.Lattice.N5
    Algebra.Lattice.Op Algebra.Lattice.Ordered Algebra.Lattice.Stacked
    Algebra.Lattice.Unicode Algebra.Lattice.Wide
    Algebra.Lattice.ZeroHalfOne Algebra.PartialOrd
    Algebra.PartialOrd.Instances

import-dirs:          /usr/lib/ghc-8.10.4/site-local/lattices-2.0.2
library-dirs:         /usr/lib/ghc-8.10.4/site-local/lattices-2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/lattices-2.0.2
hs-libraries:         HSlattices-2.0.2-81ke987MRYbJioKmaDJnwG
depends:
    QuickCheck-2.14.2-3W2gU4yWpUZKQgtIeJuCof base-4.14.1.0
    base-compat-0.11.2-JggHr2fdYLe83DSFk1MYK3 containers-0.6.2.1
    deepseq-1.4.4.0 hashable-1.3.2.0-5x51STP8vZMKBx9J0CoY3R
    integer-logarithms-1.0.3.1-8l1ymRbE3rBG8A7FKIRWkt
    semigroupoids-5.3.5-I7K5lOE3CADHcaDuIVDvsg
    tagged-0.8.6.1-A3E8I7zg2qBFE9O5vQsg6C transformers-0.5.6.2
    universe-base-1.1.2-Ae51cn93meYTTwmfGaBig
    universe-reverse-instances-1.1.1-8bz3qgTw5Qy3WgLZHTSj9T
    unordered-containers-0.2.14.0-GPjR30wZWJTEZLMkucvmDm

haddock-interfaces:   /usr/share/doc/haskell-lattices/html/lattices.haddock
haddock-html:         /usr/share/doc/haskell-lattices/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lattices-2.0.2-90-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lattices.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 lattices
version:              2.0.2
visibility:           public
id:                   lattices-2.0.2-40QFsAov1Nh3E6iZn7XdeM
key:                  lattices-2.0.2-40QFsAov1Nh3E6iZn7XdeM
license:              BSD-3-Clause
copyright:
    (C) 2010-2015 Maximilian Bolingbroke, 2016-2019 Oleg Grenrus

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Maximilian Bolingbroke <batterseapower@hotmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             http://github.com/phadej/lattices/
synopsis:
    Fine-grained library for constructing and manipulating lattices

description:
    In mathematics, a lattice is a partially ordered set in which every two
    elements @x@ and @y@ have a unique supremum (also called a least upper bound, join, or @x /\\ y@)
    and a unique infimum (also called a greatest lower bound, meet, or @x \\/ y@).

    This package provide type-classes for different lattice types, as well
    as a class for the partial order.

category:             Math
abi:                  52a6d805ab4729c0b0fbd61ec8dac2a5
exposed:              True
exposed-modules:
    Algebra.Heyting Algebra.Heyting.Free Algebra.Heyting.Free.Expr
    Algebra.Lattice Algebra.Lattice.Divisibility
    Algebra.Lattice.Dropped Algebra.Lattice.Free
    Algebra.Lattice.Free.Final Algebra.Lattice.Levitated
    Algebra.Lattice.Lexicographic Algebra.Lattice.Lifted
    Algebra.Lattice.M2 Algebra.Lattice.M3 Algebra.Lattice.N5
    Algebra.Lattice.Op Algebra.Lattice.Ordered Algebra.Lattice.Stacked
    Algebra.Lattice.Unicode Algebra.Lattice.Wide
    Algebra.Lattice.ZeroHalfOne Algebra.PartialOrd
    Algebra.PartialOrd.Instances

import-dirs:          /usr/lib/ghc-8.10.5/site-local/lattices-2.0.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/lattices-2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/lattices-2.0.2
hs-libraries:         HSlattices-2.0.2-40QFsAov1Nh3E6iZn7XdeM
depends:
    QuickCheck-2.14.2-EY3HyfbcTB28zfII1FrkZg base-4.14.2.0
    base-compat-0.11.2-Eyusxyk2CrTGloLdon9bIK containers-0.6.4.1
    deepseq-1.4.4.0 hashable-1.3.2.0-IDkVQhKLyXDF7itJntNZ2M
    integer-logarithms-1.0.3.1-BDgIIkoswVLGQoPIf73qBL
    semigroupoids-5.3.5-LjKaiT9AMSBzaoDHrtBFc
    tagged-0.8.6.1-F25vmSN4H5fEaMJYsLgYMV transformers-0.5.6.2
    universe-base-1.1.2-l0uN6IC78lEp3At676i8J
    universe-reverse-instances-1.1.1-5BITNnnDyj33NQX9EqpOuE
    unordered-containers-0.2.14.0-1OFWlQlrCvvLaIazZ0Uw3i

haddock-interfaces:   /usr/share/doc/haskell-lattices/html/lattices.haddock
haddock-html:         /usr/share/doc/haskell-lattices/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
